@@ -8,6 +8,9 @@ module Gemojione
 
       @emoji_by_name = {}
       @emoji_by_moji = {}
+      @emoji_by_ascii = {}
+      @emoji_by_code = {}
+      @emoji_by_keyword = {}
 
       emoji_list.each do |key, emoji_hash|
 
@@ -20,10 +23,24 @@ module Gemojione
           @emoji_by_name[aliased] = emoji_hash if aliased
         end
 
+        emoji_hash['aliases_ascii'].each do |emoji_ascii|
+          @emoji_by_ascii[emoji_ascii] = emoji_hash if emoji_ascii
+        end
+
+        code = emoji_hash['shortname']
+        @emoji_by_code[code] = emoji_hash if code
+
         moji = emoji_hash['moji']
         @emoji_by_moji[moji] = emoji_hash if moji
+
+        emoji_hash['keywords'].each do |emoji_keyword|
+          @emoji_by_keyword[emoji_keyword] ||= []
+          @emoji_by_keyword[emoji_keyword] << emoji_hash
+        end
       end
-      @emoji_moji_regex = /#{@emoji_by_moji.keys.join('|')}/
+
+      @emoji_code_regex = /#{@emoji_by_code.keys.map{|ec| Regexp.escape(ec)}.join('|')}/
+      @emoji_moji_regex = /#{@emoji_by_moji.keys.map{|ec| Regexp.escape(ec)}.join('|')}/
     end
 
     def find_by_moji(moji)
@@ -34,12 +51,20 @@ module Gemojione
       @emoji_by_name[name]
     end
 
+    def find_by_ascii(ascii)
+      @emoji_by_ascii[ascii]
+    end
+
+    def find_by_keyword(keyword)
+      @emoji_by_keyword[keyword]
+    end
+
     def unicode_moji_regex
       @emoji_moji_regex
     end
 
-    def images_path
-      File.expand_path("../../assets/images", File.dirname(__FILE__))
+    def shortname_moji_regex
+      @emoji_code_regex
     end
   end
 end
